@@ -177,6 +177,24 @@ class WSMECRUDTest(CubicWebServerTC):
         self.assertEqual(1, len(data['in_group']))
         self.assertIn('modification_date', data['in_group'][0])
 
+    def test_cwuser_entity_get_fetch_typed_relation(self):
+        with self.admin_access.repo_cnx() as cnx:
+            cnx.find('CWGroup', name=u'managers').one().cw_set(
+                created_by=cnx.find('CWUser', login=u'admin').one())
+            cnx.commit()
+        self.web_login()
+        url = 'cwuser/admin?fetch=<created_by[CWGroup]'
+        res = self.web_request(
+            url, headers={"Accept": "application/json"})
+        if '<!DOCTYPE html>' in res.body:
+            import html2text
+            print html2text.html2text(res.body)
+        data = json.loads(res.body)
+        self.assertEqual(200, res.status, data)
+        self.assertEqual(u"admin", data['login'])
+        self.assertEqual(1, len(data['<created_by']))
+        self.assertIn('modification_date', data['<created_by'][0])
+
     def test_cwgroup_post(self):
         self.web_login()
         url = 'cwgroup'
