@@ -21,6 +21,7 @@ import base64
 import inspect
 import itertools
 import json
+import re
 
 import six
 import wsme
@@ -205,6 +206,8 @@ class Base(six.with_metaclass(BaseMeta, wsme.types.Base)):
             if isinstance(attr, wsattr):
                 attr.finalize_init(cls)
 
+    _rtype_re = re.compile(u'(?P<rtype>[^.[]+)\[(?P<etypes>[^\]]+)\]')
+
     def from_entity(self, entity, keyonly=False, fetch=()):
         self.eid = entity.eid
         self.modification_date = entity.modification_date
@@ -213,6 +216,11 @@ class Base(six.with_metaclass(BaseMeta, wsme.types.Base)):
             # Append the modification_date
             return
 
+        typed_fetch = {
+            m.group('rtype'): m.group('etypes').split(',')
+            for m in (
+                self._rtype_re.match(f) for f in fetch) if m is not None}
+
         for attr in self._wsme_attributes:
             if not isinstance(attr, wsattr):
                 continue
@@ -227,14 +235,21 @@ class Base(six.with_metaclass(BaseMeta, wsme.types.Base)):
                 ]
 
             if wsme.types.isarray(attr.datatype):
-                if not attr.name in fetch and not subfetch:
+                if not attr.name in fetch \
+                        and not attr.name in typed_fetch \
+                        and not subfetch:
                     continue
 
-            try:
-                value = getattr(entity, attr.rname)
-            except Unauthorized:
-                # XXX set value = Forbidden ?
-                continue
+            if attr.name in typed_fetch:
+                value = entity.related(
+                    attr.rtype, role=attr.role, entities=True,
+                    targettypes=typed_fetch[attr.name])
+            else:
+                try:
+                    value = getattr(entity, attr.rname)
+                except Unauthorized:
+                    # XXX set value = Forbidden ?
+                    continue
 
             if not attr.isfinal:
                 attr_keyonly = not subfetch
